@@ -1,7 +1,10 @@
 from abc import ABC, abstractmethod
 
+from .handler import MessageHandler
+
 
 class MessageListener(ABC):
+
     @abstractmethod
     def start_listening(self):
         pass
@@ -9,3 +12,7 @@ class MessageListener(ABC):
     @abstractmethod
     def stop_listening(self):
         pass
+
+    @abstractmethod
+    def add_handler(self, handler: MessageHandler):
+        pass
