@@ -1,4 +1,6 @@
 import json
+from typing import List
+
 import pika
 
 from ...domain.handler import MessageHandler
@@ -10,9 +12,13 @@ class RabbitMessageListener(MessageListener):
         self,
         connection_string: str,
         queue: str,
-        message_handler: MessageHandler,
+        message_handler: MessageHandler = None,
     ):
-        self.__message_handler = message_handler
+        self.__message_handlers: List[MessageHandler] = []
+
+        if message_handler: # Due to compatibility reasons
+            self.__message_handlers.append(message_handler)
+
         self.connection = pika.BlockingConnection(
             pika.URLParameters(connection_string)
         )
@@ -21,7 +27,8 @@ class RabbitMessageListener(MessageListener):
         self.channel.basic_consume(queue, self.on_reception, auto_ack=True)
 
     def on_reception(self, ch, method, properties, body):
-        self.__message_handler.on_msg(json.loads(body.decode()))
+        for handler in self.__message_handlers:
+            handler.on_msg(json.loads(body.decode()))
 
     def start_listening(self):
         self.channel.start_consuming()
@@ -29,3 +36,6 @@ class RabbitMessageListener(MessageListener):
     def stop_listening(self):
         self.channel.stop_consuming()
         self.connection.close()
+
+    def add_handler(self, handler: MessageHandler):
+        self.__message_handlers.append(handler)
